@@ -66,9 +66,6 @@ sub _parse {
     my $text = shift;
     foreach my $line (split $NL_RE, $text) {
         next if not $line;
-
-        $line =~ s!,\s+(\d{4})\s+(\d{4}),\s+!, $1, $2, !g;
-
         my $match = ($line =~ $LINE_RE);
         ### assert: $match
         my $set_intspan = $1;
@@ -214,11 +211,11 @@ Debian::LicenseReconcile::CopyrightDatum - copyright data as an object
 
 =head1 VERSION
 
-Version 0.17
+Version 0.5
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.5';
 
 =head1 DESCRIPTION
 
@@ -253,7 +250,7 @@ This method returns a boolean indicating whether the object contains the argumen
 The method will respect the argument if it is a
 L<Debian::LicenseReconcile::CopyrightDatum> and otherwise stringify and parse it.
 It may also take an optional reference. If this is set on failing to
-verify containment the reason found will be placed in that reference.
+veryify containment the reason found will be placed in that reference.
 
 =head2 copyright_holders 
 
@@ -274,7 +271,7 @@ Nicholas Bamber, C<< <nicholas at periapt.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012, 2015, Nicholas Bamber C<< <nicholas at periapt.co.uk> >>.
+Copyright 2012 Nicholas Bamber C<< <nicholas at periapt.co.uk> >>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
