@@ -4,7 +4,33 @@ use 5.006;
 use strict;
 use warnings;
 use base qw(Debian::LicenseReconcile::Filter);
-use Email::Address::XS 1.01;
+use Readonly;
+
+Readonly my $ACTUAL_NAME_RE => '\pL[\s\pL\-\'\.]*\pL';
+
+# See http://www.faqs.org/rfcs/rfc2822.html
+# Section 3.4.1
+use Email::Address;
+Readonly my $EMAIL_RE => $Email::Address::addr_spec;
+
+Readonly my $EMAIL_CHANGES_RE => qr{
+    ^                           # beginining of line
+    \s+\*\s                     # item marker
+    Email\schange:\s            # email change token
+    ($ACTUAL_NAME_RE)           # actual name
+    \s+->\s+                    # gap between name and email
+    ($EMAIL_RE)                 # email address
+    $                           # end of line
+}xms;
+
+Readonly my $PERSON_PARSE_RE => qr{
+    \A                          # beginining of string
+    ($ACTUAL_NAME_RE)           # actual name
+    \s                          # gap
+    \<$EMAIL_RE\>               # logged email
+    \z                          # end of string
+}xms;
+
 
 sub get_info {
     my $self = shift;
@@ -16,23 +42,17 @@ sub get_info {
         my $date        = $_->Date;
         my @date_pieces = split( " ", $date );
         my $year        = $date_pieces[3];
-        if (my %changes = ($_->Changes =~ m/^\s+\*\sEmail\schange:\s+(.*?)\s+->\s+(.*?)\s*$/xmsg)) {
+        if (my %changes = ($_->Changes =~ m/$EMAIL_CHANGES_RE/xmsg)) {
             # This way round since we are going backward in time thru changelog
             foreach my $p (keys %changes) {
-                # Parse bare email address; undef if it not an email address
-                my $address = Email::Address::XS->parse_bare_address($changes{$p})->address();
-                if ($address) {
-                    $changes{$p} = $address;
-                } else {
-                    delete $changes{$p};
-                }
+                $changes{$p} =~ s{[\s\n]+$}{}xms;
             }
             %email_changes = (
                 %changes,
                 %email_changes
             );
         }
-        if (my $name = Email::Address::XS->parse($person)->phrase()) {
+        if (my ($name) = ($person =~ $PERSON_PARSE_RE)) {
             if (exists $email_changes{$name}) {
                 $person = "$name <$email_changes{$name}>";
             }
@@ -76,11 +96,11 @@ Debian::LicenseReconcile::Filter::ChangeLog - parses changelog
 
 =head1 VERSION
 
-Version 0.17
+Version 0.5
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.5';
 
 
 =head1 SYNOPSIS
@@ -126,7 +146,7 @@ appropriate copyright declaration is:
 
 =item Copyright (C) 2007-2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2011-2012, 2015, Nicholas Bamber <nicholas@periapt.co.uk>
+=item Copyright (C) 2011-2012, Nicholas Bamber <nicholas@periapt.co.uk>
 
 =back
 
