@@ -27,28 +27,16 @@ Readonly my %LICENSE_MAPPING => (
     'Apache (v2.0)' => 'Apache-2.0',
     'GPL' => 'GPL-2',
     'GPL-2' => 'GPL-2',
-    'GPL (v1)' => 'GPL-1',
-    'GPL (v1 or later)' => 'GPL-1+',
-    'LGPL (v2.1 or later)' => 'LGPL-2.1+',
-    'LGPL (v2.1)' => 'LGPL-2.1',
-    'LGPL (v2.1 or v3)' => 'LGPL-2.1 or LGPL-3',
-    'LGPL (v2 or v3)' => 'LGPL-2 or LGPL-3',
-    'LGPL (v3 or later)' => 'LGPL-3+',
-    'MPL (v2.0)' => 'MPL-2.0',
-    'Public domain' => 'public-domain',
     'GPL (v2)' => 'GPL-2',
     'GPL (v2 or later)' => 'GPL-2+',
-    'GPL (v3)' => 'GPL-3',
-    'GPL (v3 or later)' => 'GPL-3+',
-    'LGPL (v2)' => 'LGPL-2',
+    'LGPL (v2)' => 'LGPL',
     'zlib/libpng' => 'zlib/libpng',
     'BSD (4 clause)' => 'BSD-4-clause',
     'BSD (2 clause)' => 'BSD-2-clause',
     'BSD (3 clause)' => 'BSD-3-clause',
-    'Artistic (v2.0)' => 'Artistic-2.0',
 );
 
-Readonly my $SCRIPT => "/usr/bin/licensecheck --no-conf -c '.+'";
+Readonly my $SCRIPT => '/usr/bin/licensecheck --no-conf';
 
 Readonly my $PARSE_RE => qr{
     ^                           # beginning of line
@@ -156,7 +144,7 @@ sub _get_raw_data {
         $commands .= ' --recursive';
     }
     $commands .= " $subject" ;
-    my $output = `$commands 2> /dev/null`;
+    my $output = `$commands`;
     while ($output =~ /$PARSE_RE/g) {
         my $file = substr($1, 1+length $self->{directory});
         $self->{raw}->{$file} = {
@@ -196,11 +184,11 @@ Debian::LicenseReconcile::LicenseCheck - wrapper around licensecheck
 
 =head1 VERSION
 
-Version 0.17
+Version 0.5
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.5';
 
 
 =head1 SYNOPSIS
@@ -250,7 +238,7 @@ Nicholas Bamber, C<< <nicholas at periapt.co.uk> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012, 2015, Nicholas Bamber C<< <nicholas at periapt.co.uk> >>.
+Copyright 2012 Nicholas Bamber C<< <nicholas at periapt.co.uk> >>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
