@@ -12,10 +12,9 @@ sub get_files {
     my $directory = shift;
     my @files = ();
     find(sub {
-        return if -d $_; # avoids warnings with substr() for $_ eq $directory
-        my $shortenedname = substr($File::Find::name,length($directory)+1);
-        return if $shortenedname =~ m{\A(?:\.git|\.svn|\.pc)};
-        push @files, $shortenedname;
+        return if $File::Find::name =~ m{\A\.git};
+        return if $File::Find::name =~ m{\A\.pc};
+        push @files, substr($File::Find::name,length($directory)+1) if ! -d $_;
     }, $directory);
     return sort @files;
 }
@@ -26,11 +25,11 @@ Debian::LicenseReconcile::Utils - various just about describable utilities
 
 =head1 VERSION
 
-Version 0.17
+Version 0.5
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.5';
 
 
 =head1 SYNOPSIS
